@@ -36,6 +36,8 @@
 
 #define QT_FEATURE_wasm_exceptions -1
 
+#define QT_FEATURE_wasm_jspi -1
+
 #define QT_FEATURE_zstd 1
 
 #define QT_FEATURE_thread 1
@@ -52,14 +54,16 @@
 
 #define QT_FEATURE_opensslv30 1
 
+#define QT_FEATURE_test_gui 1
 
-#define QT_VERSION_STR "6.8.0"
+
+#define QT_VERSION_STR "6.9.1"
 
 #define QT_VERSION_MAJOR 6
 
-#define QT_VERSION_MINOR 8
+#define QT_VERSION_MINOR 9
 
-#define QT_VERSION_PATCH 0
+#define QT_VERSION_PATCH 1
 
 #define QT_COPYRIGHT "Copyright (C) The Qt Company Ltd. and other contributors."
 #if !defined(QT_SHARED) && !defined(QT_STATIC)
@@ -92,3 +96,4 @@
 #define QT_COMPILER_SUPPORTS_RDSEED 1
 #define QT_COMPILER_SUPPORTS_SHA 1
 #define QT_LINKED_OPENSSL
+#define QT_GUI_TEST 1
